@@ -88,19 +88,19 @@ class QtGraphicDevice:
   public:
     QGraphicsScene& getScene() { return *scene_; }
 
-    void begin() throw (Exception);
+    void begin();
     void end();
 
     void setCurrentForegroundColor(const RGBColor& color);
     void setCurrentBackgroundColor(const RGBColor& color);
     void setCurrentFont(const Font& font);
     void setCurrentPointSize(unsigned int size);
-    void setCurrentLineType(short type) throw (Exception);
+    void setCurrentLineType(short type);
 
     void drawLine(double x1, double y1, double x2, double y2);
     void drawRect(double x, double y, double width, double height, short fill = FILL_EMPTY);
     void drawCircle(double x, double y, double radius, short fill = FILL_EMPTY);
-    void drawText(double x, double y, const std::string& text, short hpos = TEXT_HORIZONTAL_LEFT, short vpos = TEXT_VERTICAL_BOTTOM, double angle = 0) throw (UnvalidFlagException);
+    void drawText(double x, double y, const std::string& text, short hpos = TEXT_HORIZONTAL_LEFT, short vpos = TEXT_VERTICAL_BOTTOM, double angle = 0);
     
     void comment(const std::string& comment) {}
 
